@@ -38,6 +38,18 @@ if FOAM_REF_VERSION( ">=", "010700" ) or FOAM_BRANCH_VERSION( "dev", ">=", "0106
     pass
 
 
+#----------------------------------------------------------------------------------------
+if FOAM_VERSION( ">=", "020000" ):
+    from rhoCentralFlux.r2_0_0 import *
+    pass
+
+
+#----------------------------------------------------------------------------------------
+if FOAM_VERSION( ">=", "020100" ):
+    from rhoCentralFlux.r2_1_0 import *
+    pass
+
+
 #----------------------------------------------------------------------------------------
 def entry_point():
     try:
